@@ -149,13 +149,17 @@ where
 
 #[cfg(test)]
 mod tests {
-    use crate::packet::Packet;
-    use crate::recvmmsg::recv_mmsg;
-    use crate::sendmmsg::{batch_send, multi_target_send, SendPktsError};
-    use solana_sdk::packet::PACKET_DATA_SIZE;
-    use std::{
-        io::ErrorKind,
-        net::{IpAddr, Ipv4Addr, Ipv6Addr, SocketAddr, UdpSocket},
+    use {
+        crate::{
+            packet::Packet,
+            recvmmsg::recv_mmsg,
+            sendmmsg::{batch_send, multi_target_send, SendPktsError},
+        },
+        solana_sdk::packet::PACKET_DATA_SIZE,
+        std::{
+            io::ErrorKind,
+            net::{IpAddr, Ipv4Addr, Ipv6Addr, SocketAddr, UdpSocket},
+        },
     };
 
     #[test]
